----------------------------------------------------------------------------------
-- ********* 'FleaFPGA Uno' Platform VHDL top-level module ***********
-- This is basically a wrapper allows connection of user projects to 
-- FleaFPGA Uno's on-board hardware
--
-- Creation Date: 30th October 2015
-- Author: Valentin Angelovski
--
-- 2015 - Valentin Angelovski
----------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.numeric_std.ALL;



entity FleaFPGA_Uno_E1 is

	port(
	-- System clock input from onboard 25MHz oscillator
	sys_clock		: in		std_logic;	-- main clock input from 25MHz clock source
	-- Master reset control line
	Shield_reset	: inout		std_logic;  -- Buffered reset signal out to GPIO header
	
	-- Digital Video Output - control lines
	LVDS_Red		: out		std_logic;	-- main clock input from external clock source
	LVDS_Green		: out		std_logic;	-- main clock input from external RC reset circuit
	LVDS_Blue		: out		std_logic;
	LVDS_ck			: out		std_logic;
	
	-- User LEDs
	User_LED1		: out		std_logic;
	User_LED2		: out		std_logic;

	-- User GPIO accessible from the shield header

	GPIO_wordport	: inout 	std_logic_vector(15 downto 0);
	GPIO_pullup		: out 	std_logic_vector(15 downto 0);

	-- User push button
	User_PB1		: in		std_logic;
	
	-- Sigma Delta ADC channels (x6) - input comparator and error out lines
	ADC0_Comp_in	: inout		std_logic;
	ADC0_Error_out	: inout		std_logic;
	ADC1_Comp_in	: inout		std_logic;
	ADC1_Error_out	: inout		std_logic;
	ADC2_Comp_in	: inout		std_logic;
	ADC2_Error_out	: inout		std_logic;
	ADC3_Comp_in	: inout		std_logic;
	ADC3_Error_out	: inout		std_logic;	
	ADC4_Comp_in	: inout		std_logic; 
	ADC4_Error_out	: inout		std_logic;
	ADC5_Comp_in	: inout		std_logic;
	ADC5_Error_out	: inout		std_logic;

	-- SRAM interface (For use with 512Kx8bit Fast SRAM)
	SRAM_Addr		: out		std_logic_vector(18 downto 0);	-- SRAM address bus
	SRAM_Data		: inout		std_logic_vector(7 downto 0);	-- data bus to/from SRAM
	SRAM_n_cs		: out		std_logic;
	SRAM_n_oe		: out		std_logic;
	SRAM_n_we		: out		std_logic;
	
	-- Stereo (PWM) audio out interface			
	Audio_l			: out		std_logic;
	Audio_r			: out		std_logic; 


	-- SPI1 to Flash ROM
	spi1_miso		: in 		std_logic;
	spi1_mosi		: out 		std_logic;
	spi1_clk		: out 		std_logic;
	spi1_cs			: out 		std_logic;
	
	-- PS2 interface
	PS2_clk1		: inout		std_logic;
	PS2_data1		: inout		std_logic;	

	-- UART interface
	slave_rx_i		: in		std_logic;
	slave_tx_o		: out		std_logic  
	
	);  
end FleaFPGA_Uno_E1;


architecture arch of FleaFPGA_Uno_E1 is


-- Top-level local signal declarations go here!
   
begin

-- Housekeeping logic for unwanted peripherals on FleaFPGA Uno board goes here..
-- (Note: comment out any of the following code lines if peripheral is required)

--User_LED1 <= '0';
User_LED2 <= '0'; 	-- (Must be set to '1' if using the WiFi option - becomes 'module enable') 
--GPIO_pullup(0) <= '1'; (Must be set to '1' if using the WiFi option)

spi1_cs <= '1'; 
SRAM_n_cs <= '1';

  -- User HDL component entitites go here!
  -- Note: user_module1 illustrates how to integrate a simple blinky LED logic module
  
 user_module1 : entity work.blinky

    port map(
		clk => sys_clock,
		blink_LED => User_LED1
    );


end architecture;
